# `MaayanLab`

## `MaayanLab.harmonizome`

* <http://amp.pharm.mssm.edu/Harmonizome/documentation>

## `MaayanLab.archs4`

Process [HDF5](https://www.hdfgroup.org/) files from download page,
using [h5py](https://docs.h5py.org/en/stable/index.html).

* <https://maayanlab.cloud/archs4/>
* <https://maayanlab.cloud/archs4/download.html>
